@@ -1,88 +1,3 @@
-"""# Paker
-
-[![Build](https://github.com/desty2k/paker/actions/workflows/build.yml/badge.svg)](https://github.com/desty2k/paker/actions/workflows/build.yml)
-[![Version](https://img.shields.io/pypi/v/paker)](https://pypi.org/project/paker/)
-[![Version](https://img.shields.io/pypi/dm/paker)](https://pypi.org/project/paker/)
-
-
-Paker is module for serializing and deserializing Python modules and packages.
-It was inspired by [httpimporter](https://github.com/operatorequals/httpimport).
-
-## How it works
-Paker dumps entire package structure to JSON dict.
-When loading package back, package is recreated with its submodules and subpackages.
-
-## Installation
-From PyPI
-
-```shell
-pip install paker
-```
-
-From source
-
-```shell
-git clone https://github.com/desty2k/paker.git
-cd paker
-pip install .
-```
-
-## Usage
-In these examples we will use paker to serialize [mss](https://pypi.org/project/mss/) package.
-
-### CLI
-
-To dump module to JSON dict use `dump` command:
-
-```shell
-paker dump mss
-```
-
-To recreate module from JSON dict use `load`:
-
-```shell
-paker load mss.json
-```
-
-### In Python script
-
-```python
-
-import paker
-import logging
-
-file = "mss.json"
-logging.basicConfig(level=logging.NOTSET)
-
-# install mss using `pip install mss`
-# serialize module
-with open(file, "w+") as f:
-    paker.dump("mss", f, indent=4)
-
-# now you can uninstall mss using `pip uninstall mss -y`
-# load package back from dump file
-with open(file, "r") as f:
-    loader = paker.load(f)
-
-import mss
-with mss.mss() as sct:
-    sct.shot()
-
-# remove loader and clean the cache
-loader.unload()
-
-# this will throw error
-import mss
-
-```
-
-## Bugs
-
-Loading modules from `.pyd` files does not work.
-
-"""
-
-
 import os
 import sys
 import json
@@ -90,7 +5,7 @@ import logging
 import argparse
 from paker import dump
 
-__version__ = "0.3.2"
+__version__ = "0.3.5"
 
 
 def _dump(args):
@@ -106,10 +21,33 @@ def _dump(args):
         dump(mod, f, indent=indent)
 
 
-def _load(args):
+def _list(args):
     path = args.module[0]
     with open(path, "r") as f:
         mod_dict = json.loads(f.read())
+    return _recursive_list(mod_dict)
+
+
+def _recursive_list(mod_dict: dict, parent=""):
+    for key, value in mod_dict.items():
+        if value["type"] == "package":
+            if parent:
+                key = parent + "." + key
+            print("P {}".format(key))
+            _recursive_list(value["modules"], parent=key)
+        else:
+            if parent:
+                key = parent + "." + key
+            print("M {}".format(key))
+
+
+def _load(args):
+    path = args.module[0]
+    with open(path, "r", encoding="utf-8") as f:
+        mod_dict = json.loads(f.read())
+    output = os.path.abspath(args.output)
+    os.makedirs(output, exist_ok=True)
+    os.chdir(output)
     return _recursive_load(mod_dict)
 
 
@@ -132,7 +70,7 @@ def _parser():
     parser = argparse.ArgumentParser(
         prog='paker',
         formatter_class=argparse.RawDescriptionHelpFormatter,
-        description=__doc__,
+        description="Import Python modules from JSON documents.",
         epilog='See "paker <command> -h" for more information '
                'on a specific command.'
     )
@@ -150,7 +88,8 @@ def _parser():
         'dump',
         aliases=['d'],
         formatter_class=argparse.RawDescriptionHelpFormatter,
-        help='Dump package to JSON dict'
+        help='Dump package to JSON dict',
+        description="Dump package to JSON dict"
     )
     cparser.add_argument('module', nargs=1, metavar='MODULE',
                          help='Module name')
@@ -166,13 +105,26 @@ def _parser():
         'load',
         aliases=['l'],
         formatter_class=argparse.RawDescriptionHelpFormatter,
-        help='Recreate module from JSON dict'
+        help='Recreate module from JSON dict',
+        description="Recreate module from JSON dict"
     )
     cparser.add_argument('module', nargs=1, metavar='MODULE',
                          help='Path to JSON document with module')
     cparser.add_argument('-O', '--output', default='.', metavar='PATH',
                          help='Output directory path, default is "%(default)s"')
     cparser.set_defaults(func=_load)
+
+    # list modules and packages in json file
+    cparser = subparsers.add_parser(
+        'list',
+        aliases=['ls'],
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        help='List modules and packages in JSON document',
+        description="List modules and packages in JSON document"
+    )
+    cparser.add_argument('module', nargs=1, metavar='MODULE',
+                         help='Path to JSON document with module')
+    cparser.set_defaults(func=_list)
     return parser
 
 
