@@ -1,9 +1,8 @@
 import sys
 import logging
-import _frozen_importlib_external as _bootstrap_external
+from os import sep as path_sep
 
 _module_type = type(sys)
-path_sep = _bootstrap_external.path_sep
 
 
 class jsonimporter:
@@ -97,7 +96,7 @@ class jsonimporter:
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        pass
+        self.unload()
 
     def unload_module(self, module):
         if isinstance(module, _module_type):
@@ -110,6 +109,7 @@ class jsonimporter:
     def unload(self):
         if self in sys.meta_path:
             sys.meta_path.remove(self)
-        for module_name in self.module_cache.keys():
+        for module_name in list(self.module_cache.keys()):
+            del self.module_cache[module_name]
             if module_name in sys.modules:
                 del sys.modules[module_name]
